# node-mailchimp

A node.js wrapper for the MailChimp API.

_node-mailchimp_ exposes the following features of the MailChimp API to your node.js application:
 
 * MailChimp API (Versions 1.3, 1.2 and 1.1)
 * MailChimp Export API (Version 1.0)
 * MailChimp Webhooks 

Further information on the MailChimp API and its features is available at [http://www.mailchimp.com/api/](http://www.mailchimp.com/api/)

## Installation

Installing using npm (node package manager):

    npm install mailchimp
    
If you don't have npm installed or don't want to use it:

    cd ~/.node_libraries
    git clone git://github.com/gomfunkel/node-mailchimp.git mailchimp

Please note that parts of _node-mailchimp_ depend on [request](http:/github.com/mikeal/request) by [Mikeal Rogers](http://github.com/mikeal). This library needs to be installed for the API and Export API to work.

## Usage

Information on how to use the three features of the MailChimp API can be found below. Further information on the API methods available can be found at [http://www.mailchimp.com/api/](http://www.mailchimp.com/api/). You can also find further information on how to obtain an API key, how to set up Webhooks in your MailChimp account and much more on the MailChimp API pages.

### MailChimp API

_MailChimpAPI_ takes two arguments. The first argument is your API key, which you can find in your MailChimp Account. The second argument is an options object which can contain the following options:

 * `version` The API version to use (1.1, 1.2 or 1.3). Defaults to 1.3.
 * `secure` Whether or not to use secure connections over HTTPS (true/false). Defaults to false.
 
The callback function for each API method gets one argument, an object with all information retrieved or an error message if an error occurred.

Example:

    var MailChimpAPI = require('mailchimp').MailChimpAPI;
    
    var apiKey = 'Your MailChimp API Key';
    
    try { 
        var api = new MailChimpAPI(apiKey, { version : '1.3', secure : false });
    } catch (error) {
        console.log('Error: ' + error);
    }
    
    api.campaigns({ start: 0, limit: 25 }, function (data) {
        if (data.error)
            console.log('Error: '+data.error+' ('+data.code+')');
        else
            console.log(JSON.stringify(data)); // Do something with your data!
    });
    
    api.campaignStats({ cid : '/* CAMPAIGN ID */' }, function (data) {
        if (data.error)
            console.log('Error: '+data.error+' ('+data.code+')');
        else
            console.log(JSON.stringify(data)); // Do something with your data!
    });
    
### MailChimp Export API

_MailChimpExportAPI_ takes two arguments. The first argument is your API key, which you can find in your MailChimp Account. The second argument is an options object which can contain the following options:

 * `version` The Export API version to use, currently on 1.0 is available and supported. Defaults to 1.0.
 * `secure` Whether or not to use secure connections over HTTPS (true/false). Defaults to false.
 
The callback function for the only Export API method at the moment (_list_) gets one argument, an object with all information retrieved or an error message if an error occurred. 

Example:

    var MailChimpExportAPI = require('mailchimp').MailChimpExportAPI;
    
    var apiKey = 'Your MailChimp API Key';

    try { 
        var exportApi = new MailChimpExportAPI(apiKey, { version : '1.0', secure: false });
    } catch (error) {
        console.log('Error: ' + error);
    }

    exportApi.list({ id : '/* LIST ID */'  }, function (data) {
        if (data.error)
            console.log('Error: '+data.error+' ('+data.code+')');
        else
            console.log(data); // Do something with your data!
    });
    
### MailChimp Webhooks

_MailChimpWebhook_ takes one argument, an options object which can contain the following options:

 * `port` The port the server is going to listen on. Defaults to 8100.
 * `secret` Secret key as suggested on the Webhook page which is then simply added as a pathname to the Webhook URL in your MailChimp account and checked for. Nothing too fancy but a small enhancement to security. Leave empty (default setting) if you don't want to use a secret key. Example: If you set the secret to 'ChimpSecret' you need to enter the Webhook URL http://www.yourdomain.com/ChimpSecret in the MailChimp Webhook settings.
 * `secure` Credentials as generated by the crypto module. If present HTTPS support is enabled for the server. Defaults to false. 

You can register the following events. The callback function for each of these events receive two arguments. The first argument is an object with the information retrieved, the second argument contains metadata like when the event occurred.

 * `subscribe` Emitted when someone subscribes to your list.
 * `unsubscribe` Emitted when someone unsubscribes from your list.
 * `profile` Emitted when someone updates his profile.
 * `upemail` Emitted when someone changes his email address. Please note that you will receive a `profile` event at the same time.
 * `cleaned` Emitted when an email address is cleaned from you list.
  
Example:

    var MailChimpWebhook = require('mailchimp').MailChimpWebhook;
    
    var webhook = new MailChimpWebhook();
    
    webhook.on('error', function (message) {
        console.log('Error: '+message);
    });
    
    webhook.on('subscribe', function (data, meta) {
        console.log(data.email+' subscribed to your newsletter!'); // Do something with your data!
    });
    
    webhook.on('unsubscribe', function (data, meta) {
        console.log(data.email+' unsubscribed from your newsletter!'); // Do something with your data!
    });
    
## License

_node-mailchimp_ is licensed under the MIT License. (See LICENSE) 